pub struct VaultSource { /* private fields */ }Expand description
A Source for the config library that loads configurations from HashiCorp Vault.
This source connects to a HashiCorp Vault server and loads a secret from the version 2 of the KV (Key-Value) engine. The values from the secret are included in the configuration as flat key-value pairs.
Example
use config_vault::VaultSource;
let vault = VaultSource::new(
"http://vault.example.com:8200".to_string(),
"my-token".to_string(),
"secret".to_string(),
"dev".to_string(),
);Implementations
Sourceimpl VaultSource
impl VaultSource
pub fn builder() -> VaultSourceBuilder